.. -*- coding: utf-8 -*-

Changelog
=========

1.1.1 (2023-11-03)
------------------

- Drop python 3.7 support.
  [gforcada]

- Test against python 3.12.
  [gforcada]

- Use `pyproject.toml` rather than `setup.py`.
  [gforcada]

- Switch from `setuptools` to `hatchling`.
  [gforcada]

- Switch to `main` branch.
  [gforcada]

- Use `tox` and `pre-commit` to ease project maintenance.
  [gforcada]

1.0.0 (2022-10-09)
------------------

- Pin dependencies. [gforcada]

- Test/QA with GitHub actions. [gforcada]

- Overhaul testing. [gforcada]

0.2.post0 (2017-05-31)
----------------------
- Release universal wheels
  [gforcada]

0.2 (2017-05-31)
----------------
- Added support for sublimetext (stdin/filename handling)
  [iham]

0.1 (2015-09-15)
----------------
- Initial release
  [gforcada]

- Create the flake8 plugin per se.
  [gforcada]

